@@ -31,7 +31,6 @@
 #include <IOKit/pwr_mgt/RootDomain.h>
 #include <IOKit/assert.h>
 
-#include <machine/ansi.h>
 #ifndef offsetof
 #include <stddef.h>
 #endif
@@ -2287,8 +2286,6 @@ bool AppleVCP::doIntegerSet( OSDictionary* params, const OSSymbol* sym, UInt32 v
 bool ApplePanel::start( IOService * provider )
 {
     OSData * data;
-    OSIterator * iter;
-    IOService * next;
 
     if( !super::start( provider))
         return( false );
